/*
*  
*  $Id: eventosginkgo.h 4742 2012-02-23 10:57:03Z tovar $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma once

#include <api/ievento.h>

#define ginkgoEVT_Core_ModificacionFichero 1
#include "modificacionfichero.h"

#define ginkgoEVT_Core_AddFicheroHistorial 2
#include "addficherohistorial.h"

#define ginkgoEVT_Core_ModificacionImagen  3
#include "modificacionimagen.h"

#define ginkgoEVT_Core_ModificacionWidget  4
#include "modificacionwidget.h"

#define ginkgoEVT_Core_Render              5
#include "render.h"

#define ginkgoEVT_Core_Herramientas        6
#include "herramientas.h"

#define ginkgoEVT_Core_MensajesUsuario     7
#include "mensajes.h"

#define ginkgoEVT_Core_Estilo              8
#include "estilo.h"

#define ginkgoEVT_Core_ProgresoComando     9
#include "progresocomando.h"

#define ginkgoEVT_Core_HandleDICOM           10
#include "handledicom.h"

#define ginkgoEVT_Core_UpdateAvailable     11
#include "updateavailable.h"

#define ginkgoEVT_Core_Views     12
#include "views.h"

#define ginkgoEVT_Core_DeleteFile			 13
#define ginkgoEVT_Core_UpdateFile			 14
#include "filehistory.h"

#define ginkgoEVT_Core_HideSplashWindow	 15
#include "hidesplashwindow.h"

#define ginkgoEVT_Core_Integration     16
#define ginkgoEVT_Core_HL7SendRequest  17
#include "integration.h"
///el rango 100-199 esta reservado para el historial

